@@ -11,10 +11,27 @@ from tiddlyweb.store import Store
 from tiddlywebplugins.utils import get_store
 
 
+@make_command()
+def removefieldwithvalue(args):
+  """A utility that will remove a field from all tiddlers in a bag.. Usage: removefield <bag> <fieldname>"""
+  bag_name = args[0]
+  field_name = args[1]
+  field_value = args[2]
+  store = get_store(config)
+
+  bag = store.get(Bag(bag_name))
+  for tiddler in bag.list_tiddlers():
+    tid = store.get(tiddler)
+    if field_name in tid.fields:
+      if tid.fields[field_name] == field_value:
+        del tid.fields[field_name]
+        print "deleted field %s from %s which matched %s"%(field_name,tid.title,field_value)
+        store.put(tid)
+      
         
 @make_command()
 def removefield(args):
-  """A utility that will remove a field from all tiddlers in a bag.. Usage: removefield <bag> <fieldname>"""
+  """A utility that will remove a field from all tiddlers in a bag.. Usage: removefield <bag> <fieldname> <value>"""
   bag_name = args[0]
   field_name = args[1]
   store = get_store(config)
@@ -27,8 +44,27 @@ def removefield(args):
       print "deleted field %s from %s"%(field_name,tid.title)
       store.put(tid)
 
+@make_command()
+def mapfield(args):
+  """A utility that will remove a field from all tiddlers in a bag.. Usage: removefield <bag> <fieldname> <oldvalue> <newvalue>"""
+  bag_name = args[0]
+  field_name = args[1]
+  oldvalue = args[2]
+  newvalue = args[3]
+  store = get_store(config)
+
+  bag = store.get(Bag(bag_name))
+  for tiddler in bag.list_tiddlers():
+    tid = store.get(tiddler)
+    if field_name in tid.fields:
+      if tid.fields[field_name] == oldvalue:
+        tid.fields[field_name] = newvalue
+        print "renamed field %s from %s to %s which matched in %s"%(field_name,oldvalue,newvalue,tid.title)
+        store.put(tid)
+      
 @make_command()
 def renamefield(args):
+  """A utility that will rename a field.. Usage: renamefield <bag> <oldfieldname> <newfieldname>"""
   bag_name = args[0]
   old_field_name = args[1]
   new_field_name = args[2]
